@@ -1,7 +1,7 @@
-package Search::Elasticsearch::Client::1_0::Direct::Indices;
-$Search::Elasticsearch::Client::1_0::Direct::Indices::VERSION = '1.99';
+package Search::Elasticsearch::Client::0_90::Direct::Indices;
+$Search::Elasticsearch::Client::0_90::Direct::Indices::VERSION = '2.00';
 use Moo;
-with 'Search::Elasticsearch::Role::API::1_0';
+with 'Search::Elasticsearch::Role::API::0_90';
 with 'Search::Elasticsearch::Role::Client::Direct';
 __PACKAGE__->_install_api('indices');
 
@@ -13,11 +13,11 @@ __PACKAGE__->_install_api('indices');
 
 =head1 NAME
 
-Search::Elasticsearch::Client::1_0::Direct::Indices - A client for running index-level requests
+Search::Elasticsearch::Client::0_90::Direct::Indices - A client for running index-level requests
 
 =head1 VERSION
 
-version 1.99
+version 2.00
 
 =head1 DESCRIPTION
 
@@ -48,28 +48,9 @@ Query string parameters:
     C<master_timeout>,
     C<timeout>
 
-See the L<create index docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-create-index.html>
+See the L<create index docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-create-index.html>
 for more information.
 
-=head2 C<get()>
-
-    $response = $e->indices->get(
-        index   => 'index'   | \@indices    # optional
-        feature => 'feature' | \@features   # optional
-    );
-
-Returns the aliases, settings, mappings, and warmers for the specified indices.
-The C<feature> parameter can be set to none or more of: C<_settings>, C<_mappings>,
-C<_warmers> and C<_aliases>.
-
-See the L<get index docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-get-index.html>.
-
-Query string parameters:
-    C<allow_no_indices>,
-    C<expand_wildcards>,
-    C<ignore_unavailable>,
-    C<local>
-
 =head2 C<exists()>
 
     $bool = $e->indices->exists(
@@ -79,13 +60,7 @@ Query string parameters:
 The C<exists()> method returns C<1> or the empty string to indicate
 whether the specified index or indices exist.
 
-Query string parameters:
-    C<allow_no_indices>,
-    C<expand_wildcards>,
-    C<ignore_unavailable>,
-    C<local>
-
-See the L<index exists docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-indices-exists.html>
+See the L<index exists docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-indices-exists.html>
 for more information.
 
 =head2 C<delete()>
@@ -97,13 +72,10 @@ for more information.
 The C<delete()> method deletes the specified indices.
 
 Query string parameters:
-    C<allow_no_indices>,
-    C<expand_wildcards>,
-    C<ignore_unavailable>,
     C<master_timeout>,
     C<timeout>
 
-See the L<delete index docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-delete-index.html>
+See the L<delete index docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-delete-index.html>
 for more information.
 
 =head2 C<close()>
@@ -116,31 +88,25 @@ The C<close()> method closes the specified indices, reducing resource usage
 but allowing them to be reopened later.
 
 Query string parameters:
-    C<allow_no_indices>,
-    C<expand_wildcards>,
-    C<ignore_unavailable>
     C<master_timeout>,
     C<timeout>
 
-See the L<close index docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-open-close.html>
+See the L<close index docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-open-close.html>
 for more information.
 
 =head2 C<open()>
 
     $response = $e->indices->open(
-        index => 'index' | \@indices    # required
+        index => 'index' | \@indices    # optional
     );
 
 The C<open()> method opens closed indices.
 
 Query string parameters:
-    C<allow_no_indices>,
-    C<expand_wildcards>,
-    C<ignore_unavailable>
     C<master_timeout>,
     C<timeout>
 
-See the L<open index docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-open-close.html>
+See the L<open index docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-open-close.html>
 for more information.
 
 =head2 C<clear_cache()>
@@ -161,12 +127,12 @@ Query string parameters:
     C<filter_cache>,
     C<filter_keys>,
     C<id>,
-    C<id_cache>,
+    C<ignore_indices>,
     C<ignore_unavailable>,
-    C<query_cache>,
+    C<index>,
     C<recycler>
 
-See the L<clear_cache docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-clearcache.html>
+See the L<clear_cache docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-clearcache.html>
 for more information.
 
 =head2 C<refresh()>
@@ -182,10 +148,10 @@ happens automatically once every second by default.
 Query string parameters:
     C<allow_no_indices>,
     C<expand_wildcards>,
-    C<force>,
+    C<ignore_indices>,
     C<ignore_unavailable>
 
-See the L<refresh index docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-refresh.html>
+See the L<refresh index docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-refresh.html>
 for more information.
 
 =head2 C<flush()>
@@ -203,30 +169,11 @@ Query string parameters:
     C<expand_wildcards>,
     C<force>,
     C<full>,
+    C<ignore_indices>,
     C<ignore_unavailable>,
-    C<wait_if_ongoing>
+    C<refresh>
 
-See the L<flush index docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-flush.html>
-for more information.
-
-=head2 C<flush_synced()>
-
-    $respnse = $e->indices->flush_synced(
-        index => 'index' | \@indices    # optional
-    );
-
-The C<flush_synced()> method does a synchronised L<flush()> on the primaries and replicas of
-all the specified indices.  In other words, after flushing it tries to write a C<sync_id>
-on the primaries and replicas to mark them as containing the same documents.  During
-recovery, if a replica has the same C<sync_id> as the primary, then it doesn't need to check
-whether the segment files on primary and replica are the same, and it can move on
-directly to just replaying the translog.  This can greatly speed up recovery.
-
-Synced flushes happens automatically in the background on indices that have not received any
-writes for a while, but the L<flush_synced()> method can be used to trigger this process
-manually, eg before shutting down.  Any new commits immediately break the sync.
-
-See the L<flush synced docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/flush.html>
+See the L<flush index docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-flush.html>
 for more information.
 
 =head2 C<optimize()>
@@ -243,48 +190,25 @@ Query string parameters:
     C<allow_no_indices>,
     C<expand_wildcards>,
     C<flush>,
+    C<ignore_indices>,
     C<ignore_unavailable>,
     C<max_num_segments>,
     C<only_expunge_deletes>,
+    C<refresh>,
     C<wait_for_merge>
 
-See the L<optimize index docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-optimize.html>
+See the L<optimize index docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-optimize.html>
 for more information.
 
-=head2 C<get_upgrade()>
+=head2 C<snapshot_index()>
 
-    $response = $e->indices->get_upgrade(
+    $response = $e->indices->snapshot_index(
         index => 'index' | \@indices    # optional
     );
 
-The C<get_upgrade()> method returns information about which indices need to be
-upgraded, which can be done with the C<upgrade()> method.
+Deprecated.
 
-Query string parameters:
-    C<allow_no_indices>,
-    C<expand_wildcards>,
-    C<human>,
-    C<ignore_unavailable>
-
-See the L<upgrade docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-upgrade.html>
-for more information.
-
-=head2 C<upgrade()>
-
-    $response = $e->indices->upgrade(
-        index => 'index' | \@indices    # optional
-    );
-
-The C<upgrade()> method upgrades all segments in the specified indices to the latest format.
-
-Query string parameters:
-    C<allow_no_indices>,
-    C<expand_wildcards>,
-    C<ignore_unavailable>,
-    C<only_ancient_segments>,
-    C<wait_for_completion>
-
-See the L<upgrade docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-upgrade.html>
+See the L<snapshot_index docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/>
 for more information.
 
 =head1 MAPPING METHODS
@@ -318,14 +242,11 @@ For instance:
     );
 
 Query string parameters:
-    C<allow_no_indices>,
-    C<expand_wildcards>,
-    C<ignore_unavailable>,
     C<ignore_conflicts>,
     C<master_timeout>,
     C<timeout>
 
-See the L<put_mapping docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-put-mapping.html>
+See the L<put_mapping docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-put-mapping.html>
 for more information.
 
 =head2 C<get_mapping()>
@@ -338,13 +259,7 @@ for more information.
 The C<get_mapping()> method returns the type definitions for one, more or
 all types in one, more or all indices.
 
-Query string parameters:
-    C<allow_no_indices>,
-    C<expand_wildcards>,
-    C<ignore_unavailable>,
-    C<local>
-
-See the L<get_mapping docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-get-mapping.html>
+See the L<get_mapping docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-get-mapping.html>
 for more information.
 
 =head2 C<get_field_mapping()>
@@ -360,20 +275,13 @@ for more information.
 The C<get_field_mapping()> method returns the field definitions for one, more or
 all fields in one, more or all types and indices.
 
-Query string parameters:
-    C<allow_no_indices>,
-    C<expand_wildcards>,
-    C<ignore_unavailable>,
-    C<include_defaults>,
-    C<local>
-
-See the L<get_mapping docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-get-field-mapping.html>
+See the L<get_mapping docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-get-field-mapping.html>
 for more information.
 
 =head2 C<exists_type()>
 
     $bool = $e->indices->exists_type(
-        index => 'index' | \@indices    # required,
+        index => 'index' | \@indices    # optional,
         type  => 'type'  | \@types      # required
     );
 
@@ -383,17 +291,17 @@ in all specified indices, and returns C<1> or the empty string.
 Query string parameters:
     C<allow_no_indices>,
     C<expand_wildcards>,
-    C<ignore_unavailable>,
-    C<local>
+    C<ignore_indices>,
+    C<ignore_unavailable>
 
-See the L<exists_type docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-types-exists.html>
+See the L<exists_type docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-types-exists.html>
 for more information.
 
 =head2 C<delete_mapping()>
 
     $response = $e->indices->delete_mapping(
         index => 'index' | \@indices    # required,
-        type  => 'type'  | \@types      # required
+        type  => 'type'                 # required
     );
 
 The C<delete_mapping()> method deletes the type mappings (and all documents of
@@ -402,7 +310,7 @@ that type) in all specified indices.
 Query string parameters:
     C<master_timeout>
 
-See the L<delete_mapping docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-delete-mapping.html>
+See the L<delete_mapping docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-delete-mapping.html>
 for more information.
 
 =head1 ALIAS METHODS
@@ -429,36 +337,36 @@ Query string parameters:
     C<master_timeout>,
     C<timeout>
 
-See the L<update_aliases docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-aliases.html>
+See the L<update_aliases docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-aliases.html>
 for more information.
 
 =head2 C<get_aliases()>
 
+The C<get_aliases()> method is deprecated in favour of L</get_alias()>.
+
     $result = $e->indices->get_aliases(
-        index   => 'index' | \@indices,     # optional
-        alias   => 'alias' | \@aliases      # optional
+        index   => 'index' | \@indices      # optional
     );
 
 The C<get_aliases()> method returns a list of aliases per index for all
 the specified indices.
 
 Query string parameters:
-    C<local>,
     C<timeout>
 
-See the L<get_aliases docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-aliases.html>
+See the L<get_aliases docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-aliases.html>
 for more information.
 
 =head2 C<put_alias()>
 
     $response = $e->indices->put_alias(
-        index => 'index' | \@indices,       # required
+        index => 'index',                   # required
         name  => 'alias',                   # required
 
         body  => { alias defn }             # optional
     );
 
-The C<put_alias()> method creates an index alias. For instance:
+The C<put_alias()> method creates a single index alias. For instance:
 
     $response = $e->indices->put_alias(
         index => 'my_index',
@@ -472,7 +380,7 @@ Query string parameters:
     C<master_timeout>,
     C<timeout>
 
-See the L<put_alias docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-aliases.html>
+See the L<put_alias docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-aliases.html>
 for more information.
 
 =head2 C<get_alias()>
@@ -488,10 +396,10 @@ aliases in the specified indices.
 Query string parameters:
     C<allow_no_indices>,
     C<expand_wildcards>,
-    C<ignore_unavailable>,
-    C<local>
+    C<ignore_indices>,
+    C<ignore_unavailable>
 
-See the L<get_alias docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-aliases.html>
+See the L<get_alias docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-aliases.html>
 for more information.
 
 =head2 C<exists_alias()>
@@ -507,34 +415,33 @@ whether the specified aliases exist in the specified indices.
 Query string parameters:
     C<allow_no_indices>,
     C<expand_wildcards>,
-    C<ignore_unavailable>,
-    C<local>
+    C<ignore_indices>,
+    C<ignore_unavailable>
 
-See the L<exists_alias docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-aliases.html>
+See the L<exists_alias docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-aliases.html>
 for more information.
 
 =head2 C<delete_alias()>
 
     $response = $e->indices->delete_alias(
-        index   => 'index' | \@indices        # required,
-        name    => 'alias' | \@aliases        # required
+        index   => 'index',                 # required
+        name    => 'alias'                  # required
     );
 
-The C<delete_alias()> method deletes one or more aliases from one or more
-indices.
+The C<delete_alias()> method deletes a single alias in a single index.
 
 Query string parameters:
     C<master_timeout>,
     C<timeout>
 
-See the L<delete_alias docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-aliases.html>
+See the L<delete_alias docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-aliases.html>
 for more information.
 
 =head1 SETTINGS METHODS
 
 =head2 C<put_settings()>
 
-    $response = $e->indices->put_settings(
+    $response = $e->indices->get_settings(
         index   => 'index' | \@indices      # optional
 
         body    => { settings }
@@ -550,33 +457,21 @@ indices or all indices. For instance:
     );
 
 Query string parameters:
-    C<allow_no_indices>,
-    C<expand_wildcards>,
-    C<flat_settings>,
-    C<ignore_unavailable>,
     C<master_timeout>
 
-See the L<put_settings docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-update-settings.html>
+See the L<put_settings docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-update-settings.html>
 for more information.
 
 =head2 C<get_settings()>
 
     $result = $e->indices->get_settings(
         index   => 'index' | \@indices      # optional
-        name    => 'name'  | \@names        # optional
     );
 
 The C<get_settings()> method retrieves the index settings for the specified
 indices or all indices.
 
-Query string parameters:
-    C<allow_no_indices>,
-    C<expand_wildcards>,
-    C<flat_settings>,
-    C<ignore_unavailable>,
-    C<local>
-
-See the L<get_settings docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-get-settings.html>
+See the L<get_settings docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-get-settings.html>
 for more information.
 
 =head1 TEMPLATE METHODS
@@ -591,47 +486,22 @@ for more information.
 The C<put_template()> method is used to create or update index templates.
 
 Query string parameters:
-    C<create>,
-    C<flat_settings>,
     C<master_timeout>,
-    C<op_type>,
     C<order>,
-    C<timeout>,
-    C<version>,
-    C<version_type>
+    C<timeout>
 
-See the L<put_template docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-templates.html>
+See the L<put_template docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-templates.html>
 for more information.
 
 =head2 C<get_template()>
 
     $result = $e->indices->get_template(
-        name  => 'template'                 # optional
+        name  => 'template'                 # required
     );
 
 The C<get_template()> method is used to retrieve a named template.
 
-Query string parameters:
-    C<flat_settings>,
-    C<local>,
-    C<master_timeout>
-
-See the L<get_template docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-templates.html>
-for more information.
-
-=head2 C<exists_template()>
-
-    $result = $e->indices->exists_template(
-        name  => 'template'                 # required
-    );
-
-The C<exists_template()> method is used to check whether the named template exists.
-
-Query string parameters:
-    C<local>,
-    C<master_timeout>
-
-See the L<get_template docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-templates.html>
+See the L<get_template docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-templates.html>
 for more information.
 
 =head2 C<delete_template()>
@@ -644,11 +514,9 @@ The C<delete_template()> method is used to delete a named template.
 
 Query string parameters:
     C<master_timeout>,
-    C<timeout>,
-    C<version>,
-    C<version_type>
+    C<timeout>
 
-See the L<delete_template docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-templates.html>
+See the L<delete_template docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-templates.html>
 for more information.
 
 =head1 WARMER METHODS
@@ -657,7 +525,6 @@ for more information.
 
     $response = $e->indices->put_warmer(
         index   => 'index' | \@indices,     # optional
-        type    => 'type'  | \@types,       # optional
         name    => 'warmer',                # required
 
         body    => { warmer defn }          # required
@@ -676,38 +543,28 @@ to user searches.  For instance:
     );
 
 Query string parameters:
-    C<allow_no_indices>,
-    C<expand_wildcards>,
-    C<ignore_unavailable>,
     C<master_timeout>
 
-See the L<put_warmer docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-warmers.html>
+See the L<put_warmer docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-warmers.html>
 for more information.
 
 =head2 C<get_warmer()>
 
     $response = $e->indices->get_warmer(
         index   => 'index'  | \@indices,    # optional
-        type    => 'type'   | \@types,      # optional
         name    => 'warmer' | \@warmers,    # optional
     );
 
 The C<get_warmer()> method is used to retrieve warmers by name.
 
-Query string parameters:
-    C<allow_no_indices>,
-    C<expand_wildcards>,
-    C<ignore_unavailable>,
-    C<local>
-
-See the L<get_warmer docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-warmers.html>
+See the L<get_warmer docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-warmers.html>
 for more information.
 
 =head2 C<delete_warmer()>
 
     $response = $e->indices->get_warmer(
         index   => 'index'  | \@indices,    # required
-        name    => 'warmer' | \@warmers,    # required
+        name    => 'warmer' | \@warmers,    # optional
     );
 
 The C<delete_warmer()> method is used to delete warmers by name.
@@ -715,7 +572,7 @@ The C<delete_warmer()> method is used to delete warmers by name.
 Query string parameters:
     C<master_timeout>
 
-See the L<delete_warmer docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-warmers.html>
+See the L<delete_warmer docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-warmers.html>
 for more information.
 
 =head1 STATS METHODS
@@ -723,59 +580,58 @@ for more information.
 =head2 C<stats()>
 
     $result = $e->indices->stats(
-        index   => 'index'  | \@indices      # optional
-        metric  => 'metric' | \@metrics      # optional
-    );
-
-The C<stats()> method returns statistical information about one, more or all
-indices. By default it returns all metrics, but you can limit which metrics
-are returned by specifying the C<metric>.
-
-Allowed metrics are:
-    C<_all>,
-    C<completion>
-    C<docs>,
-    C<fielddata>,
-    C<filter_cache>,
-    C<flush>,
-    C<get>,
-    C<id_cache>,
-    C<indexing>,
-    C<merge>,
-    C<percolate>,
-    C<query_cache>,
-    C<refresh>,
-    C<search>,
-    C<segments>,
-    C<store>,
-    C<warmer>
-
-Query string parameters:
-    C<completion_fields>,
-    C<fielddata_fields>,
-    C<fields>,
-    C<groups>,
-    C<human>,
-    C<level>,
-    C<types>
-
-See the L<stats docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-stats.html>
-for more information.
-
-=head2 C<recovery()>
-
-    $result = $e->indices->recovery(
         index   => 'index' | \@indices      # optional
     );
 
-Provides insight into on-going shard recoveries.
+The C<stats()> method returns statistical information about one, more or all
+indices.  Use the query string parameters to specify what information you
+want returned.
 
 Query string parameters:
-    C<active_only>,
-    C<detailed>,
-    C<human>
+    C<all>,
+    C<allow_no_indices>,
+    C<clear>,
+    C<completion>,
+    C<completion_fields>,
+    C<docs>,
+    C<expand_wildcards>,
+    C<fielddata>,
+    C<fielddata_fields>,
+    C<fields>,
+    C<filter_cache>,
+    C<flush>,
+    C<get>,
+    C<groups>,
+    C<id_cache>,
+    C<ignore_indices>,
+    C<ignore_unavailable>,
+    C<indexing>,
+    C<merge>,
+    C<refresh>,
+    C<search>,
+    C<store>,
+    C<warmer>
 
-See the L<recovery docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-recovery.html>
+See the L<stats docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-stats.html>
+for more information.
+
+=head2 C<status()>
+
+    $result = $e->indices->status(
+        index   => 'index' | \@indices      # optional
+    );
+
+Deprecated.
+
+Query string parameters:
+    C<allow_no_indices>,
+    C<expand_wildcards>,
+    C<ignore_indices>,
+    C<ignore_unavailable>,
+    C<recovery>,
+    C<snapshot>
+
+See the L<status docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-status.html>
 for more information.
 
 =head2 C<segments()>
@@ -790,10 +646,10 @@ that an index contains.
 Query string parameters:
     C<allow_no_indices>,
     C<expand_wildcards>,
-    C<human>,
+    C<ignore_indices>,
     C<ignore_unavailable>
 
-See the L<segments docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-segments.html>
+See the L<segments docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-segments.html>
 for more information.
 
 =head1 QUERY AND ANALYSIS METHODS
@@ -812,24 +668,21 @@ for debugging analyzer configurations.
 
 Query string parameters:
     C<analyzer>,
-    C<char_filters>,
     C<field>,
     C<filters>,
     C<format>,
+    C<index>,
     C<prefer_local>,
-    C<rewrite>,
     C<text>,
     C<tokenizer>
 
-See the L<analyze docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-analyze.html>
+See the L<analyze docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-analyze.html>
 for more information.
 
 =head2 C<validate_query()>
 
     $result = $e->indices->validate_query(
         index   => 'index' | \@indices,     # optional
-        type    => 'type'  | \@types,       # optional
-
         body    => { query }
     );
 
@@ -839,18 +692,14 @@ to C<true>, in which case it includes an execution plan in the output.
 
 Query string parameters:
     C<allow_no_indices>,
-    C<analyze_wildcard>,
-    C<analyzer>,
-    C<default_operator>,
-    C<df>,
     C<expand_wildcards>,
     C<explain>,
+    C<ignore_indices>,
     C<ignore_unavailable>,
-    C<lenient>,
-    C<lowercase_expanded_terms>,
-    C<q>
+    C<q>,
+    C<source>
 
-See the L<validate_query docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-validate.html>
+See the L<validate_query docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-validate.html>
 for more information.
 
 =head1 AUTHOR
