@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Client::2_0::Direct::Cluster;
-$Search::Elasticsearch::Client::2_0::Direct::Cluster::VERSION = '1.99';
+$Search::Elasticsearch::Client::2_0::Direct::Cluster::VERSION = '2.00';
 use Moo;
 with 'Search::Elasticsearch::Role::API::2_0';
 with 'Search::Elasticsearch::Role::Client::Direct';
@@ -17,7 +17,7 @@ Search::Elasticsearch::Client::2_0::Direct::Cluster - A client for running clust
 
 =head1 VERSION
 
-version 1.99
+version 2.00
 
 =head1 DESCRIPTION
 
@@ -62,7 +62,8 @@ Returns high-level cluster stats, optionally limited to the listed nodes.
 
 Query string parameters:
     C<flat_settings>,
-    C<human>
+    C<human>,
+    C<timeout>
 
 See the L<cluster stats docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-stats.html>
 for more information.
