@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Scroll;
-$Search::Elasticsearch::Scroll::VERSION = '1.99';
+$Search::Elasticsearch::Scroll::VERSION = '2.00';
 use Moo;
 use Search::Elasticsearch::Util qw(parse_params throw);
 use namespace::clean;
@@ -95,18 +95,14 @@ sub refill_buffer {
 }
 
 #===================================
-around 'finish' => sub {
-#===================================
-    my ( $orig, $self ) = @_;
-    $orig->($self);
-    @{ $self->_buffer } = ();
-    1;
-};
-
-#===================================
-sub _clear_scroll {
+sub finish {
 #===================================
     my $self = shift;
+    return if $self->is_finished || $self->_pid != $$;
+
+    $self->_set_is_finished(1);
+    @{ $self->_buffer } = ();
+
     my $scroll_id = $self->_scroll_id or return;
     $self->_clear_scroll_id;
 
@@ -115,6 +111,7 @@ sub _clear_scroll {
         ? ( scroll_id => $scroll_id )
         : ( body => $scroll_id );
     eval { $self->es->clear_scroll(%args) };
+    return 1;
 }
 
 1;
@@ -129,7 +126,7 @@ Search::Elasticsearch::Scroll - A helper module for scrolled searches
 
 =head1 VERSION
 
-version 1.99
+version 2.00
 
 =head1 SYNOPSIS
 
@@ -156,14 +153,14 @@ until there are no more matching results, much like a cursor in an SQL
 database.
 
 Unlike paginating through results (with the C<from> parameter in
-L<search()|Search::Elasticsearch::Client::1_0::Direct/search()>),
+L<search()|Search::Elasticsearch::Client::2_0::Direct/search()>),
 scrolled searches take a snapshot of the current state of the index. Even
 if you keep adding new documents to the index or updating existing documents,
 a scrolled search will only see the index as it was when the search began.
 
 This module is a helper utility that wraps the functionality of the
-L<search()|Search::Elasticsearch::Client::1_0::Direct/search()> and
-L<scroll()|Search::Elasticsearch::Client::1_0::Direct/scroll()> methods to make
+L<search()|Search::Elasticsearch::Client::2_0::Direct/search()> and
+L<scroll()|Search::Elasticsearch::Client::2_0::Direct/scroll()> methods to make
 them easier to use.
 
 B<IMPORTANT>: Deep scrolling can be expensive.  See L</DEEP SCROLLING>
@@ -284,13 +281,13 @@ are memory constrained, you will need to take this into account.
         %search_params
     );
 
-The L<Search::Elasticsearch::Client::1_0::Direct/scroll_helper()> method loads
+The L<Search::Elasticsearch::Client::2_0::Direct/scroll_helper()> method loads
 L<Search::Elasticsearch::Scroll> class and calls L</new()>,
 passing in any arguments.
 
 You can specify a C<scroll> duration (which defaults to C<"1m">) and
 C<scroll_in_qs> (which defaults to C<false>). Any other parameters are
-passed directly to L<Search::Elasticsearch::Client::1_0::Direct/search()>.
+passed directly to L<Search::Elasticsearch::Client::2_0::Direct/search()>.
 
 The C<scroll> duration tells Elasticearch how long it should keep the scroll
 alive.  B<Note>: this duration doesn't need to be long enough to process
@@ -299,7 +296,7 @@ The expiry gets renewed for another C<scroll> period every time new
 a new batch of results is retrieved from the cluster.
 
 By default, the C<scroll_id> is passed as the C<body> to the
-L<scroll|Search::Elasticsearch::Client::1_0::Direct/scroll()> request.
+L<scroll|Search::Elasticsearch::Client::2_0::Direct/scroll()> request.
 To send it in the query string instead, set C<scroll_in_qs> to a true value,
 but be aware: when querying very many indices, the scroll ID can become
 too long for intervening proxies.
@@ -398,9 +395,9 @@ How long the original search plus all subsequent batches took, in milliseconds.
 
 =item * L<Search::Elasticsearch::Bulk/reindex()>
 
-=item * L<Search::Elasticsearch::Client::1_0::Direct/search()>
+=item * L<Search::Elasticsearch::Client::2_0::Direct/search()>
 
-=item * L<Search::Elasticsearch::Client::1_0::Direct/scroll()>
+=item * L<Search::Elasticsearch::Client::2_0::Direct/scroll()>
 
 =back
 
